==> schema-registry-common-1.0.1-sources.jar: com/amazonaws/services/schemaregistry/common/AWSSerializerInput.java <==
/*
 * Copyright 2020 Amazon.com, Inc. or its affiliates.
 * Licensed under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.amazonaws.services.schemaregistry.common;

import lombok.Builder;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.ToString;

/**
 * Encapsulates general inputs for serializer
 */
@ToString
@EqualsAndHashCode
public class AWSSerializerInput {
    @Getter
    private String schemaDefinition;

    @Getter
    private String schemaName;

    @Getter
    private String transportName;

    @Builder
    public AWSSerializerInput(String schemaDefinition, String schemaName, String transportName) {
        this.schemaDefinition = schemaDefinition;

        if (transportName != null) {
            this.transportName = transportName;
        } else {
            this.transportName = "default-stream";
        }

        if (schemaName != null) {
            this.schemaName = schemaName;
        } else {
            this.schemaName = new AWSSchemaNamingStrategyDefaultImpl().getSchemaName(transportName);
        }
    }
}

==> schema-registry-common-1.1.19-sources.jar: com/amazonaws/services/schemaregistry/common/AWSSerializerInput.java <==
/*
 * Copyright 2020 Amazon.com, Inc. or its affiliates.
 * Licensed under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.amazonaws.services.schemaregistry.common;

import lombok.Builder;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.ToString;

/**
 * Encapsulates general inputs for serializer
 */
@ToString
@EqualsAndHashCode
public class AWSSerializerInput {
    @Getter
    private String schemaDefinition;

    @Getter
    private String schemaName;

    @Getter
    private String dataFormat;

    @Getter
    private String transportName;

    @Builder
    public AWSSerializerInput(String schemaDefinition, String schemaName, String dataFormat, String transportName) {
        this.schemaDefinition = schemaDefinition;

        if (transportName != null) {
            this.transportName = transportName;
        } else {
            this.transportName = "default-stream";
        }

        if (schemaName != null) {
            this.schemaName = schemaName;
        } else {
            this.schemaName = new AWSSchemaNamingStrategyDefaultImpl().getSchemaName(transportName);
        }

        this.dataFormat = dataFormat;
    }
}
